from setuptools import setup 

setup(name="trainerai",
version="0.1.0",
description="This is A Package Used To Train Your AI Model With Data.",
author="Kaushik Shresth",
author_email="kaushikshresth07@gmail.com",install_requires=['nltk==3.7','numpy==1.22.3','torch==1.11.0'])
